==> material-ui-shell-1.3.3.tgz: package/es/providers/Menu/Provider.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React, { useEffect, useReducer } from 'react';
import PropTypes from 'prop-types';
import Context from './Context';
import useMediaQuery from '@material-ui/core/useMediaQuery';
import { setIsAuthMenuOpen, setIsMiniMode, setIsMenuOpen, setIsMobileMenuOpen, setIsMiniSwitchVisibility } from './store/actions';
import reducer from './store/reducer';

var Provider = function Provider(_ref) {
  var appConfig = _ref.appConfig,
      children = _ref.children,
      _ref$persistKey = _ref.persistKey,
      persistKey = _ref$persistKey === void 0 ? 'menu' : _ref$persistKey;

  var _ref2 = appConfig || {},
      menu = _ref2.menu;

  var initialAuthMenuOpen = menu.initialAuthMenuOpen,
      initialMiniMode = menu.initialMiniMode,
      initialMenuOpen = menu.initialMenuOpen,
      initialMobileMenuOpen = menu.initialMobileMenuOpen,
      initialMiniSwitchVisibility = menu.initialMiniSwitchVisibility,
      useWindowWatcher = menu.useWindowWatcher;
  var savedState = JSON.parse(localStorage.getItem(persistKey));

  var _useReducer = useReducer(reducer, _extends({
    isAuthMenuOpen: initialAuthMenuOpen,
    isMiniMode: initialMiniMode,
    isMenuOpen: initialMenuOpen,
    isMobileMenuOpen: initialMobileMenuOpen,
    isMiniSwitchVisibility: initialMiniSwitchVisibility
  }, savedState)),
      menuStore = _useReducer[0],
      dispatch = _useReducer[1];

  var props = {
    //setter
    toggleThis(value, newValue) {
      if (newValue === void 0) {
        newValue = null;
      }

      if (value === 'isAuthMenuOpen') {
        dispatch(setIsAuthMenuOpen(newValue !== null ? newValue : !menuStore.isAuthMenuOpen));
      } else if (value === 'isMiniMode') {
        dispatch(setIsMiniMode(newValue !== null ? newValue : !menuStore.isMiniMode));
      } else if (value === 'isMenuOpen') {
        dispatch(setIsMenuOpen(newValue !== null ? newValue : !menuStore.isMenuOpen));
      } else if (value === 'isMobileMenuOpen') {
        dispatch(setIsMobileMenuOpen(newValue !== null ? newValue : !menuStore.isMobileMenuOpen));
      } else if (value === 'isMiniSwitchVisibility') {
        dispatch(setIsMiniSwitchVisibility(newValue !== null ? newValue : !menuStore.isMiniSwitchVisibility));
      }
    },

    //getters
    isAuthMenuOpen: menuStore.isAuthMenuOpen,
    isMiniMode: menuStore.isMiniMode,
    isMenuOpen: menuStore.isMenuOpen,
    isMobileMenuOpen: menuStore.isMobileMenuOpen,
    isMiniSwitchVisibility: menuStore.isMiniSwitchVisibility
  };
  var isDesktop = useMediaQuery('(min-width:600px)');
  useEffect(function () {
    try {
      localStorage.setItem(persistKey, JSON.stringify(menuStore));
    } catch (error) {
      console.warn(error);
    }
  }, [menuStore, persistKey]);
  useEffect(function () {
    if (useWindowWatcher) {
      if (!isDesktop) {
        props.setMenuOpen(false);
        props.setMiniMode(false);
      }
    }
  }, [isDesktop, props, useWindowWatcher]);
  return /*#__PURE__*/React.createElement(Context.Provider, {
    value: _extends({
      isDesktop
    }, props)
  }, children);
};

Provider.propTypes = process.env.NODE_ENV !== "production" ? {
  children: PropTypes.any
} : {};
export default Provider;

==> material-ui-shell-1.4.0.tgz: package/es/providers/Menu/Provider.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React, { useEffect, useReducer } from 'react';
import PropTypes from 'prop-types';
import Context from './Context';
import useMediaQuery from '@material-ui/core/useMediaQuery';
import { setIsAuthMenuOpen, setIsMiniMode, setIsMenuOpen, setIsMobileMenuOpen, setIsMiniSwitchVisibility } from './store/actions';
import reducer from './store/reducer';

var Provider = function Provider(_ref) {
  var appConfig = _ref.appConfig,
      children = _ref.children,
      _ref$persistKey = _ref.persistKey,
      persistKey = _ref$persistKey === void 0 ? 'menu' : _ref$persistKey;

  var _ref2 = appConfig || {},
      menu = _ref2.menu;

  var initialAuthMenuOpen = menu.initialAuthMenuOpen,
      initialMiniMode = menu.initialMiniMode,
      initialMenuOpen = menu.initialMenuOpen,
      initialMobileMenuOpen = menu.initialMobileMenuOpen,
      initialMiniSwitchVisibility = menu.initialMiniSwitchVisibility,
      useWindowWatcher = menu.useWindowWatcher;
  var savedState = JSON.parse(localStorage.getItem(persistKey));

  var _useReducer = useReducer(reducer, _extends({
    isAuthMenuOpen: initialAuthMenuOpen,
    isMiniMode: initialMiniMode,
    isMenuOpen: initialMenuOpen,
    isMobileMenuOpen: initialMobileMenuOpen,
    isMiniSwitchVisibility: initialMiniSwitchVisibility
  }, savedState)),
      menuStore = _useReducer[0],
      dispatch = _useReducer[1];

  var props = {
    //setter
    toggleThis: function toggleThis(value, newValue) {
      if (newValue === void 0) {
        newValue = null;
      }

      if (value === 'isAuthMenuOpen') {
        dispatch(setIsAuthMenuOpen(newValue !== null ? newValue : !menuStore.isAuthMenuOpen));
      } else if (value === 'isMiniMode') {
        dispatch(setIsMiniMode(newValue !== null ? newValue : !menuStore.isMiniMode));
      } else if (value === 'isMenuOpen') {
        dispatch(setIsMenuOpen(newValue !== null ? newValue : !menuStore.isMenuOpen));
      } else if (value === 'isMobileMenuOpen') {
        dispatch(setIsMobileMenuOpen(newValue !== null ? newValue : !menuStore.isMobileMenuOpen));
      } else if (value === 'isMiniSwitchVisibility') {
        dispatch(setIsMiniSwitchVisibility(newValue !== null ? newValue : !menuStore.isMiniSwitchVisibility));
      }
    },
    //getters
    isAuthMenuOpen: menuStore.isAuthMenuOpen,
    isMiniMode: menuStore.isMiniMode,
    isMenuOpen: menuStore.isMenuOpen,
    isMobileMenuOpen: menuStore.isMobileMenuOpen,
    isMiniSwitchVisibility: menuStore.isMiniSwitchVisibility
  };
  var isDesktop = useMediaQuery('(min-width:600px)');
  useEffect(function () {
    try {
      localStorage.setItem(persistKey, JSON.stringify(menuStore));
    } catch (error) {
      console.warn(error);
    }
  }, [menuStore, persistKey]);
  useEffect(function () {
    if (useWindowWatcher) {
      if (!isDesktop) {
        props.setMenuOpen(false);
        props.setMiniMode(false);
      }
    }
  }, [isDesktop, props, useWindowWatcher]);
  return /*#__PURE__*/React.createElement(Context.Provider, {
    value: _extends({
      isDesktop: isDesktop
    }, props)
  }, children);
};

Provider.propTypes = process.env.NODE_ENV !== "production" ? {
  children: PropTypes.any
} : {};
export default Provider;
